summaryrefslogtreecommitdiffstats
path: root/bibletime/backend
diff options
context:
space:
mode:
Diffstat (limited to 'bibletime/backend')
-rw-r--r--bibletime/backend/bt_gbfhtml.cpp6
-rw-r--r--bibletime/backend/bt_osishtml.cpp2
-rw-r--r--bibletime/backend/bt_thmlhtml.cpp6
-rw-r--r--bibletime/backend/cdisplayrendering.cpp6
-rw-r--r--bibletime/backend/cdisplaytemplatemgr.cpp26
-rw-r--r--bibletime/backend/clanguagemgr.cpp6
-rw-r--r--bibletime/backend/creferencemanager.cpp12
-rw-r--r--bibletime/backend/cswordbackend.cpp2
-rw-r--r--bibletime/backend/cswordkey.cpp4
-rw-r--r--bibletime/backend/cswordmoduleinfo.cpp4
-rw-r--r--bibletime/backend/ctextrendering.cpp4
11 files changed, 39 insertions, 39 deletions
diff --git a/bibletime/backend/bt_gbfhtml.cpp b/bibletime/backend/bt_gbfhtml.cpp
index 0ab1761..3361ce0 100644
--- a/bibletime/backend/bt_gbfhtml.cpp
+++ b/bibletime/backend/bt_gbfhtml.cpp
@@ -166,7 +166,7 @@ char BT_GBFHTML::processText(sword::SWBuf& buf, const sword::SWKey * key, const
//insert the span
if (!insertedTag) { //we have to insert a new tag end and beginning, i.e. our first loop
- e.tqreplace(pos, tag.matchedLength(), "</span>");
+ e.replace(pos, tag.matchedLength(), "</span>");
pos += 7;
//skip blanks, commas, dots and stuff at the beginning, it doesn't belong to the morph code
@@ -200,7 +200,7 @@ char BT_GBFHTML::processText(sword::SWBuf& buf, const sword::SWKey * key, const
//search the existing attribute start
TQRegExp attrRegExp( isMorph ? "morph=\".+(?=\")" : "lemma=\".+(?=\")" );
attrRegExp.setMinimal(true);
- const int foundPos = e.tqfind(attrRegExp, tagAttributeStart);
+ const int foundPos = e.find(attrRegExp, tagAttributeStart);
if (foundPos != -1) {
e.insert(foundPos + attrRegExp.matchedLength(), TQString("|").append(value));
@@ -239,7 +239,7 @@ char BT_GBFHTML::processText(sword::SWBuf& buf, const sword::SWKey * key, const
}
bool BT_GBFHTML::handleToken(sword::SWBuf &buf, const char *token, sword::BasicFilterUserData *userData) {
- if (!substituteToken(buf, token)) { //more than a simple tqreplace
+ if (!substituteToken(buf, token)) { //more than a simple replace
const unsigned int tokenLength = strlen(token);
unsigned long i;
sword::SWBuf value;
diff --git a/bibletime/backend/bt_osishtml.cpp b/bibletime/backend/bt_osishtml.cpp
index 5fb1f3a..db75741 100644
--- a/bibletime/backend/bt_osishtml.cpp
+++ b/bibletime/backend/bt_osishtml.cpp
@@ -354,7 +354,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
Q_ASSERT(mod);
//if the osisRef like "GerLut:key" contains a module, use that
- int pos = ref.tqfind(":");
+ int pos = ref.find(":");
if ((pos >= 0) && ref.at(pos-1).isLetter() && ref.at(pos+1).isLetter()) {
TQString newModuleName = ref.left(pos);
diff --git a/bibletime/backend/bt_thmlhtml.cpp b/bibletime/backend/bt_thmlhtml.cpp
index e92fe30..a808bf6 100644
--- a/bibletime/backend/bt_thmlhtml.cpp
+++ b/bibletime/backend/bt_thmlhtml.cpp
@@ -140,7 +140,7 @@ char BT_ThMLHTML::processText(sword::SWBuf& buf, const sword::SWKey* key, const
//insert the span
if (!insertedTag) {
- e.tqreplace(pos, tag.matchedLength(), "</span>");
+ e.replace(pos, tag.matchedLength(), "</span>");
pos += 7;
TQString rep;
@@ -166,7 +166,7 @@ char BT_ThMLHTML::processText(sword::SWBuf& buf, const sword::SWKey* key, const
//search the existing attribute start
TQRegExp attrRegExp( isMorph ? "morph=\".+(?=\")" : "lemma=\".+(?=\")" );
attrRegExp.setMinimal(true);
- const int foundAttrPos = e.tqfind(attrRegExp, pos);
+ const int foundAttrPos = e.find(attrRegExp, pos);
if (foundAttrPos != -1) {
e.insert(foundAttrPos + attrRegExp.matchedLength(), TQString("|").append(value));
@@ -177,7 +177,7 @@ char BT_ThMLHTML::processText(sword::SWBuf& buf, const sword::SWKey* key, const
}
}
else { //attribute was not yet inserted
- const int attrPos = e.tqfind(TQRegExp("morph=|lemma="), 0);
+ const int attrPos = e.find(TQRegExp("morph=|lemma="), 0);
if (attrPos >= 0) {
TQString attr;
diff --git a/bibletime/backend/cdisplayrendering.cpp b/bibletime/backend/cdisplayrendering.cpp
index 74e3590..48445a9 100644
--- a/bibletime/backend/cdisplayrendering.cpp
+++ b/bibletime/backend/cdisplayrendering.cpp
@@ -117,7 +117,7 @@ namespace Rendering {
TQString text = oldText;
TQRegExp re("(\\b)(?=\\w)"); //word begin marker
- int pos = text.tqfind(re, 0);
+ int pos = text.find(re, 0);
while (pos != -1) { //word begin found
//qWarning("found word at %i in %i", pos, text.length());
@@ -126,7 +126,7 @@ namespace Rendering {
//qWarning("matched %s", text.mid(pos+1, 4).latin1());
//find end of word and put a marker around it
- endPos = text.tqfind(TQRegExp("\\b|[,.:]"), pos+1);
+ endPos = text.find(TQRegExp("\\b|[,.:]"), pos+1);
if ((endPos != -1) && !CToolClass::inHTMLTag(endPos, text) && (endPos - pos >= 3)) { //reuire wordslonger than 3 chars
text.insert(endPos, "</span>");
text.insert(pos, "<span class=\"word\">");
@@ -134,7 +134,7 @@ namespace Rendering {
endPos += 26;
}
}
- pos = text.tqfind(re, endPos);
+ pos = text.find(re, endPos);
}
*/
const CLanguageMgr::Language* const lang =
diff --git a/bibletime/backend/cdisplaytemplatemgr.cpp b/bibletime/backend/cdisplaytemplatemgr.cpp
index c78d7bd..797f04c 100644
--- a/bibletime/backend/cdisplaytemplatemgr.cpp
+++ b/bibletime/backend/cdisplaytemplatemgr.cpp
@@ -44,7 +44,7 @@ CDisplayTemplateMgr::~CDisplayTemplateMgr() {}
\fn CDisplayTemplateMgr::fillTemplate( const TQString& name, const TQString& title, const TQString& content )
*/
const TQString CDisplayTemplateMgr::fillTemplate( const TQString& name, const TQString& content, Settings& settings ) {
- const TQString templateName = m_templateMap.tqcontains(name) ? name : defaultTemplate();
+ const TQString templateName = m_templateMap.contains(name) ? name : defaultTemplate();
TQString displayTypeString;
@@ -145,22 +145,22 @@ const TQString CDisplayTemplateMgr::fillTemplate( const TQString& name, const TQ
// qWarning("Outputing unformated text");
const TQString t = TQString(m_templateMap[ templateName ]) //don't change the map's content directly, use a copy
- .tqreplace("#TITLE#", settings.title)
- .tqreplace("#LANG_ABBREV#", settings.langAbbrev.isEmpty() ? TQString("en") : settings.langAbbrev)
- .tqreplace("#DISPLAYTYPE#", displayTypeString)
- .tqreplace("#LANG_CSS#", langCSS)
- .tqreplace("#PAGE_DIRECTION#", settings.pageDirection)
- .tqreplace("#CONTENT#", newContent);
+ .replace("#TITLE#", settings.title)
+ .replace("#LANG_ABBREV#", settings.langAbbrev.isEmpty() ? TQString("en") : settings.langAbbrev)
+ .replace("#DISPLAYTYPE#", displayTypeString)
+ .replace("#LANG_CSS#", langCSS)
+ .replace("#PAGE_DIRECTION#", settings.pageDirection)
+ .replace("#CONTENT#", newContent);
//printf("%s\n\n", t.latin1());
return t;
/* TQString(m_templateMap[ templateName ]) //don't change the map's content directly, use a copy
- .tqreplace("#TITLE#", settings.title)
- .tqreplace("#LANG_ABBREV#", settings.langAbbrev.isEmpty() ? TQString("en") : settings.langAbbrev)
- .tqreplace("#DISPLAYTYPE#", displayTypeString)
- .tqreplace("#LANG_CSS#", langCSS)
- .tqreplace("#PAGE_DIRECTION#", settings.pageDirection)
- .tqreplace("#CONTENT#", newContent);*/
+ .replace("#TITLE#", settings.title)
+ .replace("#LANG_ABBREV#", settings.langAbbrev.isEmpty() ? TQString("en") : settings.langAbbrev)
+ .replace("#DISPLAYTYPE#", displayTypeString)
+ .replace("#LANG_CSS#", langCSS)
+ .replace("#PAGE_DIRECTION#", settings.pageDirection)
+ .replace("#CONTENT#", newContent);*/
}
diff --git a/bibletime/backend/clanguagemgr.cpp b/bibletime/backend/clanguagemgr.cpp
index df3215e..53086b4 100644
--- a/bibletime/backend/clanguagemgr.cpp
+++ b/bibletime/backend/clanguagemgr.cpp
@@ -97,7 +97,7 @@ const CLanguageMgr::LangMap& CLanguageMgr::availableLanguages() {
// for (CSwordModuleInfo* m = mods.first(); m; m = mods.next()) {
abbrev = (*it)->module()->Lang();
- if (abbrev && !abbrevs.tqcontains(abbrev)) {
+ if (abbrev && !abbrevs.contains(abbrev)) {
abbrevs.append( abbrev );
}
};
@@ -122,7 +122,7 @@ const CLanguageMgr::LangMap& CLanguageMgr::availableLanguages() {
};
const CLanguageMgr::Language* const CLanguageMgr::languageForAbbrev( const TQString& abbrev ) const {
- Language* lang = m_langMap.tqfind(abbrev);
+ Language* lang = m_langMap.find(abbrev);
if (lang) {
return lang;
@@ -131,7 +131,7 @@ const CLanguageMgr::Language* const CLanguageMgr::languageForAbbrev( const TQStr
//try to search in the alternative abbrevs
//const LangMapIterator end = m_langMap.constEnd();
for ( LangMapIterator it( m_langMap ); it.current(); ++it ) {
- if (it.current()->alternativeAbbrevs() && it.current()->alternativeAbbrevs()->tqcontains(abbrev)) {
+ if (it.current()->alternativeAbbrevs() && it.current()->alternativeAbbrevs()->contains(abbrev)) {
return it.current();
}
}
diff --git a/bibletime/backend/cswordbackend.cpp b/bibletime/backend/cswordbackend.cpp
index 53c84e0..dc316c5 100644
--- a/bibletime/backend/cswordbackend.cpp
+++ b/bibletime/backend/cswordbackend.cpp
@@ -329,7 +329,7 @@ CSwordModuleInfo* const CSwordBackend::findModuleByDescription(const TQString& d
/** This function searches for a module with the specified description */
const TQString CSwordBackend::findModuleNameByDescription(const TQString& description) {
- if (m_moduleDescriptionMap.tqcontains(description)) {
+ if (m_moduleDescriptionMap.contains(description)) {
return m_moduleDescriptionMap[description];
}
diff --git a/bibletime/backend/cswordkey.cpp b/bibletime/backend/cswordkey.cpp
index 7c11f1d..ccf79bf 100644
--- a/bibletime/backend/cswordkey.cpp
+++ b/bibletime/backend/cswordkey.cpp
@@ -81,7 +81,7 @@ const TQString CSwordKey::renderedText( const CSwordKey::TextRenderType mode ) {
if (m_module->type() == CSwordModuleInfo::Lexicon) {
m_module->snap();
/* In lexicons make sure that our key (e.g. 123) was successfully set to the module,
- i.e. the module key contains this key (e.g. 0123 tqcontains 123) */
+ i.e. the module key contains this key (e.g. 0123 contains 123) */
if ( strcasecmp(m_module->module()->getKey()->getText(), buffer)
&& !strstr(m_module->module()->getKey()->getText(), buffer)
@@ -108,7 +108,7 @@ const TQString CSwordKey::renderedText( const CSwordKey::TextRenderType mode ) {
TQString number = rx.cap(2);
TQString paddednumber = number.rightJustify(5, '0'); // Form 00123
- text.tqreplace(
+ text.replace(
TQRegExp( TQString(
"(>[^<>]+)" // Avoid replacing inside tags
"\\b(0*%1)\\b").tqarg(number) ), // And span around 0's
diff --git a/bibletime/backend/cswordmoduleinfo.cpp b/bibletime/backend/cswordmoduleinfo.cpp
index 0b665d3..ebb0cc3 100644
--- a/bibletime/backend/cswordmoduleinfo.cpp
+++ b/bibletime/backend/cswordmoduleinfo.cpp
@@ -496,7 +496,7 @@ const TQString CSwordModuleInfo::config(const CSwordModuleInfo::ConfigEntry entr
case AbsoluteDataPath: {
TQString path( getSimpleConfigEntry("AbsoluteDataPath") );
- path.tqreplace(TQRegExp("/./"), "/"); // make /abs/path/./modules/ looking better
+ path.replace(TQRegExp("/./"), "/"); // make /abs/path/./modules/ looking better
//make sure we have a trailing slash!
if (path.right(1) != "/") {
@@ -510,7 +510,7 @@ const TQString CSwordModuleInfo::config(const CSwordModuleInfo::ConfigEntry entr
TQString path(getSimpleConfigEntry("DataPath"));
if ((type() == CSwordModuleInfo::GenericBook) || (type() == CSwordModuleInfo::Lexicon)) {
- int pos = path.tqfindRev("/"); //last slash in the string
+ int pos = path.findRev("/"); //last slash in the string
if (pos != -1) {
path = path.left(pos + 1); //include the slash
diff --git a/bibletime/backend/ctextrendering.cpp b/bibletime/backend/ctextrendering.cpp
index 7ca4416..bd5b06f 100644
--- a/bibletime/backend/ctextrendering.cpp
+++ b/bibletime/backend/ctextrendering.cpp
@@ -172,7 +172,7 @@ ListCSwordModuleInfo CTextRendering::KeyTree::collectModules() const {
/*ToDo: Use the const iterators as soon as we use TQt > 3.1
const ListCSwordModuleInfo::const_iterator c_end = childMods.end();
for (ListCSwordModuleInfo::const_iterator c_it = childMods.constBegin(); c_it != c_end; ++c_it) {
- if (!modules.tqcontains(*c_it)) {
+ if (!modules.contains(*c_it)) {
modules.append(*c_it);
}
}*/
@@ -181,7 +181,7 @@ ListCSwordModuleInfo CTextRendering::KeyTree::collectModules() const {
ListCSwordModuleInfo::iterator end_it = childMods.end();
for (ListCSwordModuleInfo::iterator it(childMods.begin()); it != end_it; ++it) {
- if (!modules.tqcontains(*it)) {
+ if (!modules.contains(*it)) {
modules.append(*it);
}
}
diff --git a/bibletime/backend/creferencemanager.cpp b/bibletime/backend/creferencemanager.cpp
index 1ca0e01..a8cef48 100644
--- a/bibletime/backend/creferencemanager.cpp
+++ b/bibletime/backend/creferencemanager.cpp
@@ -159,7 +159,7 @@ const bool CReferenceManager::decodeHyperlink( const TQString& hyperlink, TQStri
if (ref.at(0) != '/' ) { //we have a module given
while (true) {
- const int pos = ref.tqfind("/");
+ const int pos = ref.find("/");
if ((pos>0) && ref.at(pos-1) != '\\') { //found a slash which is not escaped
module = ref.mid(0,pos);
@@ -179,7 +179,7 @@ const bool CReferenceManager::decodeHyperlink( const TQString& hyperlink, TQStri
}
//the key may be an osis key like "NASBLex:Moses", which sets the module, too
- // const int modPos = key.tqfind(":");
+ // const int modPos = key.find(":");
// if (modPos != -1 && key.at(modPos-1).isLetter() && key.at(modPos+1).isLetter()) {
// module = key.left(modPos);
// key = key.mid(modPos+1);
@@ -187,8 +187,8 @@ const bool CReferenceManager::decodeHyperlink( const TQString& hyperlink, TQStri
// qWarning("found the module name %s with key %s", module.latin1(), key.latin1());
// }
- //tqreplace \/ escapes with /
- key.tqreplace(TQRegExp("\\\\/"), "/");
+ //replace \/ escapes with /
+ key.replace(TQRegExp("\\\\/"), "/");
}
else if (ref.left(8).lower() == "morph://" || ref.left(10).lower() == "strongs://") { //strongs or morph URL have the same format
enum PreType {IsMorph, IsStrongs};
@@ -204,7 +204,7 @@ const bool CReferenceManager::decodeHyperlink( const TQString& hyperlink, TQStri
}
//part up to next slash is the language
- const int pos = ref.tqfind("/");
+ const int pos = ref.find("/");
if (pos>0) { //found
const TQString language = ref.mid(0,pos);
@@ -253,7 +253,7 @@ const TQString CReferenceManager::encodeReference(const TQString &module, const
}
void CReferenceManager::decodeReference(TQString &dragreference, TQString &module, TQString &reference) {
- const int pos = dragreference.tqfind(")");
+ const int pos = dragreference.find(")");
const TQString fallbackModule = dragreference.mid( 1, pos - 1);
dragreference = dragreference.mid(pos+1);